#!/usr/bin/ksh
# VERSION : 1.25
# DATE    : 11/04/05
# COPYRIGHT:
#                                                         
#                                                         
#   (C) COPYRIGHT International Business Machines Corp.   
#   2011                                            
#   All Rights Reserved                                   
#   Licensed Materials - Property of IBM                  
#   5725-C89                                              
#                                                         
#   US Government Users Restricted Rights -               
#   Use, duplication or disclosure restricted by          
#   GSA ADP Schedule Contract with IBM Corp.              
#                                                         
#                                                                       
#            NOTICE TO USERS OF THE SOURCE CODE EXAMPLES                
#                                                                       
# INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THE SOURCE CODE  
# EXAMPLES, BOTH INDIVIDUALLY AND AS ONE OR MORE GROUPS, AS IS          
# WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,            
# INCLUDING, BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF               
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE     
# RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOURCE CODE EXAMPLES,   
# BOTH INDIVIDUALLY AND AS ONE OR MORE GROUPS, IS WITH YOU.  SHOULD     
# ANY PART OF THE SOURCE CODE EXAMPLES PROVE DEFECTIVE, YOU (AND NOT    
# IBM) ASSUME THE ENTIRE COST OF ALL NECESSARY SERVICING, REPAIR OR     
# CORRECTION.  THIS PROGRAM MAY BE USED, EXECUTED, COPIED, MODIFIED     
# AND DISTRIBUTED WITHOUT ROYALTY FOR THE PURPOSE OF DEVELOPING,        
# MARKETING, OR DISTRIBUTING.                                           
#                                                                       
#                                                                       
#                                                         
#                                                                       
#                                                                       
#                                                                       
#
#
# Usage :
#  deployCC.sh { createRA | removeRA  } [ -u WAS_admin_user -p WAS_admin_password ]
#  where,
#        createRA : to install the WebSphere eXtended Transaction Runtime Resource Adapter, SCA Component, system admin contributions,
#                        CCWSample and the SMDemo Sample
#        removeRA : to remove the WebSphere eXtended Transaction Runtime Resource Adapter, SCA Component, system admin contributions,
#                        CCWSample and the SMDemo Sample
#        WAS_admin_user : WebSphere Application Server Administrative user
#        WAS_admin_password: WebSphere Application Server Administrative user's password
#
#


  debug_message()
  {
     echo $* >> ${log_file}
  }

  output_message()
  {
     debug_message $*
     echo $*
  }

  usage()
  {
    echo "Usage: `basename $0` { createRA | removeRA } [ -u WAS_admin_user -p WAS_admin_password ]"
    echo "   where,"
    echo "       createRA         : Installs the WebSphere eXtended Transaction Runtime system administration contributions,\n                          Resource Adapter, SCA Component, the supplied samples: CCWSample Sample and the SMDemo Sample"
    echo "       removeRA         : Removes the WebSphere eXtended Transaction Runtime system administration contributions,\n                          Resource Adapter, SCA Component, the supplied samples: CCWSample Sample and the SMDemo Sample"
    echo ""
    echo "If Administrative Security has been set in the WebSphere Application Server, then you need to provide the username and password."
    echo "       WAS_admin_user    : WebSphere Application Server Administrator"
    echo "       WAS_admin_password: WebSphere Application Server Administrator's password"
    echo ""        
    echo "  NOTE: This tool has to be run as a user with Administrative privileges."
        exit 1
  }

  parse()
  {
    if (( $# != 1 )) && (( $# != 5 ))
    then
        usage
    fi

    if [[ "${1}" != "createRA" ]] && [[ "${1}" != "removeRA" ]]
    then
      usage
    fi

    if (( $# == 5 ))
    then
      if [[ "${2}" = "-u" ]]
      then
        userName="${3}"
        userNameSet="true"
        if [[ "${4}"  = "-p" ]]
        then
          password="${5}"
          passwordSet="true"
        else
          usage
        fi
      elif [[ "${2}" = "-p" ]]
      then
        password="${3}"
        passwordSet="true"
        if [[ "${4}"  = "-u" ]]
        then
          userName="${5}"
          userNameSet="true"
        else
          usage
        fi

      else
        usage
      fi
    fi
  }

  initialize()
  {
    # Initial Values

    if [[ "${CICSPATH}" = "" ]]
    then
      echo "Error occurred. The environment variable: CICSPATH is not set. A new installation of WebSphere eXtended Transaction Runtime requires you to logoff and login to reflect changes in the system environment."
      exit 1
    fi
    if [[ ! -d "${CICSPATH}" ]]
    then
      echo "Error occurred. Could not locate the WebSphere eXtended Transaction Runtime installation. CICSPATH is set to ${CICSPATH} and the directory is empty." 
      exit 1
    fi
    export PATH=${PATH}:${CICSPATH}/bin:/usr/bin:/bin:/usr/sbin
    export LIBPATH=${LIBPATH}:${CICSPATH}/lib
    Machine=`uname -n`
    Node="${Machine}"Node01
    Cell="${Node}Cell"
    Server=server1
    #
    RETVAL=0
    log_file=${CICSPATH}/logs/deployCC_${1}.log 
    if [ ! -f ${CICSPATH}/logs ]
    then
      mkdir -p ${CICSPATH}/logs 
      rm -f ${log_file} 
      echo ""
      echo "The log file: ${log_file} will be created." 
      echo ""
      touch ${log_file} 
      RETVAL=$?
      if (( ${RETVAL} != 0 ))
      then
        echo "Could not create file: ${log_file}. Trying in /tmp."
        log_file=/tmp/deployCC_${1}.log
        touch ${log_file}
        RETVAL=$?
        if (( ${RETVAL} != 0 ))
        then
          echo "Error occurred. Could not create file: ${log_file}."
          exit 1
        fi
      fi
        
    fi
    # Initial Values

    #trap to remove temporary files. Comment this to keep the files to debug.
    trap "rm -f /tmp/CCWAStatusServer.log /tmp/CCWAStartServer.log /tmp/CCWAStopServer.log /tmp/removeCCRA.py /tmp/installCCRA.py 2>/dev/null  " 0 1 2 3 15
  }

  getWASInstall()
  {
    WXTRPATH=`getProperty CCW_REGION`
    if [[ "${WXTRPATH}" != "" ]]
    then
        folder_count=1
        for i in `echo ${WXTRPATH} | tr '/' ' '`
        do
          ((folder_count=${folder_count}+1))
        done
        ((folder_count=${folder_count}-7))
        WAS_PROFILE=`echo ${WXTRPATH} | cut -d'/' -f1-${folder_count}`
        export Profile=`echo ${WXTRPATH} | cut -d'/' -f${folder_count}`
        export folder_count;
    else
        output_message "Error occurred. The WebSphere eXtended Transaction Runtime container could not be located. A new installation of WebSphere eXtended Transaction Runtime requires you to execute the configureCICSServices utility before executing `basename $0`" 
        exit 1
    fi
    WAS_PROFILE_BIN="${WAS_PROFILE}/bin" 

    if [ ! -f "${WAS_PROFILE_BIN}/serverStatus.sh" ]
    then
        output_message "Error occurred. The WebSphere eXtended Transaction Runtime container could not be located. A new installation of WebSphere eXtended Transaction Runtime requires you to execute the configureCICSServices utility before executing `basename $0`" 
        exit 1
    fi
      
  }


  setRAAttributes()
  {
    CCName=CCWResourceAdapter
    CCDesc="WebSphere eXtended Transaction Runtime Resource Adapter"
    CCJNDI=eis/CCW
    CCRARFile="${CICSPATH}/lib/CCWAdapter.rar"
  }


  acceptCellName()
  { 
    ((cell_count=${folder_count}+3))

    input=`echo $WXTRPATH|cut -d'/' -f${cell_count}` 
    if [[ "${input}" != "" ]]
    then
      Cell="${input}" 
    fi

  }

  acceptNodeName()
  {
    ((node_count=${folder_count}+5))
    input=`echo $WXTRPATH|cut -d'/' -f${node_count}` 
    if [[ "${input}" != "" ]]
    then
      Node="${input}" 
    fi

  }


  acceptServerName()
  {
    ((server_count=${folder_count}+7))
    input=`echo $WXTRPATH|cut -d'/' -f${server_count}` 
    if [[ "${input}" != "" ]]
    then
      Server="${input}" 
    fi
  }

  startServer()
  {
    output_message "Attempting to start the server ${Server}." 
    output_message "A temporary file, /tmp/CCWAStartServer.log will be created. " 
    output_message "You can check the file /tmp/CCWAStartServer.log for the progress of the start server action."
    if [[ "${SERVER_STATUS}" = "STARTED" ]]
    then
      output_message "Server: ${Server} is already started."
    else
      ${WAS_PROFILE_BIN}/startServer.sh ${Server} 2>&1 | tee /tmp/CCWAStartServer.log >> ${log_file} 
      cat /tmp/CCWAStartServer.log |grep "ADMU3000I" >/dev/null 
      RETVAL=$? 
      if (( ${RETVAL} == 0 ))
      then
        output_message "Server: ${Server} is started." 
        SERVER_STATUS="STARTED"
      else
        output_message "Server: ${Server} could not be started." 
        SERVER_STATUS="STOPPED"
        return ${RETVAL} 
      fi
    fi
  }

  stopServer()
  {
    output_message "Attempting to stop the server ${Server}."
    output_message "You may be prompted for WAS administrative user name and password if required."
    output_message "A temporary file /tmp/CCWAStopServer.log will be created. " 
    output_message "You can check the file /tmp/CCWAStopServer.log for the progress of the stop server action."
    if [[ "${SERVER_STATUS}" = "STOPPED" ]]
    then
      output_message "Server: ${Server} is already stopped."
    else
      cat /dev/null > /tmp/CCWAStopServer.log
      if [[ "${userNameSet}" = "true" ]] || [[ "${passwordSet}" = "true" ]]
      then
        ${WAS_PROFILE_BIN}/stopServer.sh ${Server} -username ${userName} -password ${password}  2>&1 | tee -a /tmp/CCWAStopServer.log ${log_file}
        cat /tmp/CCWAStopServer.log |grep "ADMU4000I" >/dev/null 
        RETVAL=$? 
      else
        ${WAS_PROFILE_BIN}/stopServer.sh ${Server} 2>&1 | tee -a /tmp/CCWAStopServer.log  ${log_file}
        cat /tmp/CCWAStopServer.log |grep "ADMU4000I" >/dev/null 
        RETVAL=$? 
      fi
      if (( ${RETVAL} == 0 ))
      then
        output_message "Server: ${Server} stopped successfully." 
        SERVER_STATUS="STOPPED"
      else
        output_message "Server: ${Server} could not be stopped." 
        SERVER_STATUS="STARTED"
        return ${RETVAL}
      fi
    fi
  }

  checkServerStatus()
  {
      SERVER_STATUS="UNKNOWN"
      acceptServerName
      output_message "Checking for status of the server: ${Server}..." 
      output_message "You may be prompted for WAS administrative user name and password if required."
      output_message "A temporary file, /tmp/CCWAStatusServer.log will be created." 
      output_message "You can check the file /tmp/CCWAStatusServer.log for the progress of the status check action."
      cat /dev/null > /tmp/CCWAStatusServer.log
      if [[ "${userNameSet}" = "true" ]] || [[ "${passwordSet}" = "true" ]]
      then
        ${WAS_PROFILE_BIN}/serverStatus.sh ${Server} -username ${userName} -password ${password} 2>&1 | tee -a /tmp/CCWAStatusServer.log ${log_file}
      else
        ${WAS_PROFILE_BIN}/serverStatus.sh ${Server}  2>&1 | tee -a /tmp/CCWAStatusServer.log ${log_file}
      fi


      cat /tmp/CCWAStatusServer.log |grep "ADMU0522E" >/dev/null 
      RETVAL=$? 
      if (( ${RETVAL} == 0 ))
      then
        output_message "Error occurred. No server by name: ${Server} is found in the configuration." 
        echo "Check the log file: ${log_file} for details."
        exit 1
      fi
    
      cat /tmp/CCWAStatusServer.log |grep "ADMU0508I" >/dev/null 
      RETVAL=$? 
      if (( ${RETVAL} == 0 ))
      then
        output_message "Server: ${Server} found and is started." 
	SERVER_STATUS="STARTED"
      fi
    
      cat /tmp/CCWAStatusServer.log |grep "ADMU0509I" >/dev/null 
      RETVAL=$? 
      if (( ${RETVAL} == 0 ))
      then
        output_message "Server: ${Server} found but appears to be stopped." 
        SERVER_STATUS="STOPPED" 
      fi
      if [[ "${SERVER_STATUS}" = "UNKNOWN" ]]
      then
        output_message "Error occurred. The server: ${Server} could not be reached."
        echo "Check the log file: ${log_file} for details."
        exit 1
      fi
   
  }
  
  verifyWXTRService()
  {
    if [ ! -f `getProperty CCW_REGION`/`getProperty CCW_CONTAINER`/log/.wxtrlog ]
    then
      touch `getProperty CCW_REGION`/`getProperty CCW_CONTAINER`/log/.wxtrlog 
    fi
  }




  callWsadmin()
  {
    debug_message "$WAS_PROFILE_BIN/wsadmin.sh  will be executed with the following input:"
    cat ${1} >> ${log_file} 
    debug_message ""
    echo "You may be prompted for WAS administrative user name and password if required."
    if [[ "${userNameSet}" = "true" ]] || [[ "${passwordSet}" = "true" ]]
    then
      $WAS_PROFILE_BIN/wsadmin.sh -f ${1} -lang jython -user ${userName} -password ${password}  2>&1 | tee -a  ${log_file}
      RETVAL=$?
    else
      $WAS_PROFILE_BIN/wsadmin.sh -f ${1} -lang jython  2>&1 | tee -a  ${log_file}
      RETVAL=$?
    fi
    if (( ${RETVAL} != 0 ))
    then
      debug_message "$WAS_PROFILE_BIN/wsadmin.sh failed with error code: ${RETVAL}" 
      return ${RETVAL} 
    else
      debug_message "$WAS_PROFILE_BIN/wsadmin.sh completed."
    fi

  }

  deploySample()
  {
    echo "AdminApp.install('${CICSPATH}/samples/J2EE/${1}.war', '[ -nopreCompileJSPs -distributeApp -nouseMetaDataFromBinary -nodeployejb -appname ${1} -createMBeansForResources -noreloadEnabled -nodeployws -validateinstall warn -noprocessEmbeddedConfig -filepermission .*\.dll=755#.*\.so=755#.*\.a=755#.*\.sl=755 -noallowDispatchRemoteInclude -noallowServiceRemoteInclude -asyncRequestDispatchType DISABLED -nouseAutoLink -contextroot /${2} -MapModulesToServers [[ ${1} ${1}.war,WEB-INF/web.xml WebSphere:cell=${Cell},node=${Node},server=${Server} ]] -CtxRootForWebMod [[ ${1} ${1}.war,WEB-INF/web.xml /${2} ]]]' )" >/tmp/installCCRA.py
    echo "AdminConfig.save()" >>/tmp/installCCRA.py
    callWsadmin /tmp/installCCRA.py

    echo "queryString='node=${Node},process=${Server},type=ApplicationManager,*'">/tmp/installCCRA.py
    echo "appManager=AdminControl.queryNames( queryString )" >>/tmp/installCCRA.py
    echo "AdminControl.invoke(appManager, 'startApplication', '[${1}]')" >> /tmp/installCCRA.py

    callWsadmin /tmp/installCCRA.py
    return $? 
  }

  undeploySample()
  {
    echo "queryString='node=${Node},process=${Server},type=ApplicationManager,*'"> /tmp/removeCCRA.py
    echo "appManager=AdminControl.queryNames( queryString )" >>/tmp/removeCCRA.py
    echo "AdminControl.invoke(appManager, 'stopApplication', '[${1}]')" >> /tmp/removeCCRA.py
    callWsadmin /tmp/removeCCRA.py

    echo "AdminApp.uninstall('${1}')" > /tmp/removeCCRA.py
    echo "AdminConfig.save()" >> /tmp/removeCCRA.py

    callWsadmin /tmp/removeCCRA.py
    return $? 

  }

  createSCA()
  {
    echo "AdminTask.createEmptyBLA('[-name wxtrsca]')" > /tmp/installCCRA.py
    echo "AdminTask.importAsset('[-storageType FULL -source ${CICSPATH}/lib/wxtrsca.jar ]')" >> /tmp/installCCRA.py
    echo "AdminTask.addCompUnit('[-blaID WebSphere:blaname=wxtrsca -cuSourceID WebSphere:assetname=wxtrsca.jar ]')" >> /tmp/installCCRA.py
    echo "AdminConfig.save()" >> /tmp/installCCRA.py
    echo "AdminTask.startBLA('[-blaID WebSphere:blaname=wxtrsca ]')" >> /tmp/installCCRA.py

    callWsadmin /tmp/installCCRA.py
    return $? 
  }

  removeSCA()
  {
    echo "AdminTask.deleteCompUnit('[-blaID WebSphere:blaname=wxtrsca -cuID WebSphere:cuname=wxtr ]')" > /tmp/removeCCRA.py
    echo "AdminTask.deleteBLA('[-blaID WebSphere:blaname=wxtrsca ]')" >> /tmp/removeCCRA.py
    echo "AdminTask.deleteAsset('[-assetID WebSphere:assetname=wxtrsca.jar ]')" >> /tmp/removeCCRA.py
    echo "AdminConfig.save()" >> /tmp/removeCCRA.py

    callWsadmin /tmp/removeCCRA.py
    return $? 
  }

  createCCRA()
  { 

    echo "AdminTask.installResourceAdapter('[-rarPath $CCRARFile -nodeName ${Node} -rar.name $CCName -rar.desc \"$CCDesc\"]')" > /tmp/installCCRA.py
    echo "AdminConfig.save()" >> /tmp/installCCRA.py

    callWsadmin /tmp/installCCRA.py
    return $?
  }

  removeCCRA()
  {
    debug_message "Stopping the WebSphere eXtended Transaction Runtime container."
    ${CICSPATH}/bin/stopCICSServices  >> ${log_file} 2>&1 
    echo "ra = AdminConfig.getid('/J2CResourceAdapter:$CCName/')" > /tmp/removeCCRA.py
    echo "AdminConfig.remove(ra)" >> /tmp/removeCCRA.py
    echo "AdminConfig.save()" >> /tmp/removeCCRA.py

    callWsadmin /tmp/removeCCRA.py
    return $? 
  }

  createSysAdm()
  {

    debug_message "Setting the IEHS plugin for WebSphere eXtended Transaction Runtime system administration contributions."
    ${CICSPATH}/../bin/ws_ant.sh -f ${CICSPATH}/etc/iehs-help.ant >> ${log_file} 2>&1
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. Command: ${CICSPATH}/../bin/ws_ant.sh -f ${CICSPATH}/etc/iehs-help.ant failed with error code: ${RETVAL}."
      return 1
    fi
    

    debug_message "Installing WebSphere eXtended Transaction Runtime system administration contributions, with command: ${WAS_PROFILE_BIN}/iscdeploy.sh  -install -moduleExtension ${CICSPATH}/lib/wxtr.war -pluginId com.ibm.ws.console.wxtr" 
    ${WAS_PROFILE_BIN}/iscdeploy.sh -install -moduleExtension ${CICSPATH}/lib/wxtr.war -pluginId com.ibm.ws.console.wxtr  >> ${log_file} 2>&1 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. ${WAS_PROFILE_BIN}/iscdeploy.sh failed with error code: ${RETVAL}." 
      return 1
    fi


    debug_message "Updating ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml with WebSphere eXtended Transaction Runtime specific entry: <plugin id=\"com.ibm.ws.console.wxtr\" version=\"1.0.0\" uri=\"com.ibm.ws.console.wxtr/plugin.xml\"/>" 
    cp ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml.before.wxtr.config
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. Failed to update the file ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml."
      return 1
    fi
       
    grep -v "</feature>" ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml.before.wxtr.config  > ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. Failed to update the file ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml."
      mv ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml.before.wxtr.config ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml
      return 1
    fi
       
    echo "        <plugin id=\"com.ibm.ws.console.wxtr\" version=\"1.0.0\" uri=\"com.ibm.ws.console.wxtr/plugin.xml\"/>
</feature>" >> ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then	
      debug_message "Error occurred. Failed to update the file ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml."
      mv ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml.before.wxtr.config ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml
      return 1
    fi

    debug_message "Clearing cache entries with command: ${WAS_PROFILE_BIN}/osgiCfgInit.sh"
    ${WAS_PROFILE_BIN}/osgiCfgInit.sh >> ${log_file} 2>&1
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. ${WAS_PROFILE_BIN}/osgiCfgInit.sh failed with error code: ${RETVAL}." 
      return 1
    fi


  }

  removeSysAdm()
  {
    debug_message "Uninstalling WebSphere eXtended Transaction Runtime system administration contributions with command ${WAS_PROFILE_BIN}/iscdeploy.sh -uninstall -pluginId com.ibm.ws.console.wxtr" 
    ${WAS_PROFILE_BIN}/iscdeploy.sh -uninstall -pluginId com.ibm.ws.console.wxtr >> ${log_file} 2>&1 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. ${WAS_PROFILE_BIN}/iscdeploy.sh failed with error code: ${RETVAL}." 
      return 1
    fi

    debug_message "Updating ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml. Removing the WebSphere eXtended Transaction Runtime specific entry: <plugin id=\"com.ibm.ws.console.wxtr\" version=\"1.0.0\" uri=\"com.ibm.ws.console.wxtr/plugin.xml\"/>" 
    cp ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml.before.wxtr.unconfig 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. Failed to update the file ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml." 
      return 1
    fi
       
    grep -v "<plugin id=\"com.ibm.ws.console.wxtr\" version=\"1.0.0\" uri=\"com.ibm.ws.console.wxtr/plugin.xml\"/>" ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml.before.wxtr.unconfig  > ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. Failed to update the file ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml." 
      mv ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml.before.wxtr.unconfig ${CICSPATH}/../features/com.ibm.ws.base_6.0.0.0/feature.xml 
      return 1
    fi
       
    
    debug_message "Clearing cache entries" 
    ${WAS_PROFILE_BIN}/osgiCfgInit.sh >> ${log_file} 2>&1
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
      debug_message "Error occurred. ${WAS_PROFILE_BIN}/osgiCfgInit.sh failed with error code: ${RETVAL}." 
      return 1
    fi


  }


# main()
  parse $*
  initialize $*
  getWASInstall $*
  acceptCellName
  acceptNodeName
  setRAAttributes
  verifyWXTRService 
  
  if [[ "${1}" = "createRA" ]]
  then
    output_message ""
    output_message "------------------------------------------------------------"
    output_message ""
    output_message " Application server environment:"
    output_message ""
    output_message " Profile name: " ${Profile}
    output_message " Cell name: " ${Cell}
    output_message " Node name: " ${Node}
    output_message " Server name: " ${Server}
    output_message ""
    output_message "------------------------------------------------------------"
    output_message ""
    output_message "`basename ${0}` will perform the following actions:"
    output_message ""
    output_message "1. The WebSphere eXtended Transaction Runtime system administration contributions will be\ninstalled on the application server."
    output_message ""
    output_message "2. The WebSphere eXtended Transaction Runtime Resource Adapter with the following details\nwill be deployed on the application server."
    output_message ""
    output_message "    Name of the Resource Adapter: " ${CCName} 
    output_message "    Description for the Resource Adapter: " ${CCDesc} 
    output_message "    Resource Adapter file: \"${CCRARFile}\""
    output_message ""
    output_message "3. The WebSphere eXtended Transaction Runtime SCA Component will be deployed on \nthe application server."
    output_message ""
    output_message "4. The sample: ${CICSPATH}/samples/J2EE/CCWSample.war will be \ndeployed on the application server."
    output_message ""
    output_message "5. The sample: ${CICSPATH}/samples/J2EE/SMDemo.war will be \ndeployed on the application server."
    output_message ""
    output_message "------------------------------------------------------------"
    output_message "NOTE: `basename ${0}` will stop the WebSphere Application Server to\n install the system administration contributions and then restart it\n before installing the Resource Adapter, SCA Component and Samples."
    output_message ""
    output_message "------------------------------------------------------------"
    output_message ""
    output_message "This may take a few minutes. Please wait..."
    output_message ""
    output_message ""
    checkServerStatus


    output_message ""
    stopServer 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
	exit ${RETVAL} 
    fi

    output_message ""
    output_message "Removing WebSphere eXtended Transaction Runtime system administration contributions, if they are installed."
    removeSysAdm 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       debug_message "Ignoring error. Continuing..."
    fi
    output_message "Installing WebSphere eXtended Transaction Runtime system administration contributions."
    createSysAdm 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
        output_message "Error occurred. Failed to install the WebSphere eXtended Transaction Runtime system administration contributions. " 
        ACTION_FAILED="true"
    else
        output_message "The WebSphere eXtended Transaction Runtime system administration contributions are installed successfully."
    fi

    output_message ""
    startServer 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
	exit ${RETVAL} 
    fi


    output_message ""
    output_message "Removing the WebSphere eXtended Transaction Runtime Resource Adapter, if it is already installed."
    removeCCRA 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       debug_message "Ignoring error. Continuing..."
    fi
    output_message "Installing the WebSphere eXtended Transaction Runtime Resource Adapter." 
    createCCRA
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
        output_message "Error occurred. Failed to install WebSphere eXtended Transaction Runtime Resource Adapter. " 
        ACTION_FAILED="true"
    else
        output_message "The WebSphere eXtended Transaction Runtime Resource Adapter is installed successfully."
    fi


    output_message ""
    output_message "Removing the WebSphere eXtended Transaction Runtime SCA Component, if it is already installed."
    removeSCA 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       debug_message "Ignoring error. Continuing..."
    fi
    output_message "Installing the WebSphere eXtended Transaction Runtime SCA Component." 
    createSCA 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
        output_message "Error occurred. Failed to install WebSphere eXtended Transaction Runtime SCA Component. " 
        ACTION_FAILED="true"
    else
        output_message "The WebSphere eXtended Transaction Runtime SCA Component is installed successfully." 
    fi


    output_message ""
    output_message "Removing the sample: CCWSample, if it is already installed."
    undeploySample "CCWSample" 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       debug_message "Ignoring error. Continuing..."
    fi
    output_message "Installing the WebSphere eXtended Transaction Runtime supplied sample: CCWSample." 
    deploySample "CCWSample" "CCWSample"
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
        output_message "Error occurred. Failed to install WebSphere eXtended Transaction Runtime supplied sample: CCWSample. " 
        ACTION_FAILED="true"
    else
        output_message "The sample: CCWSample is successfully installed."
    fi


    output_message ""
    output_message "Removing the sample: SMDemo, if it is already installed."
    undeploySample "SMDemo" 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       debug_message "Ignoring error. Continuing..."
    fi
    output_message "Installing the WebSphere eXtended Transaction Runtime supplied sample: SMDemo." 
    deploySample "SMDemo" "SMSample"
    if (( ${RETVAL} != 0 ))
    then
        output_message "Error occurred. Failed to install WebSphere eXtended Transaction Runtime supplied sample: SMDemo. " 
        ACTION_FAILED="true"
    else
        output_message "The sample: SMDemo is successfully installed."
    fi
    output_message "Starting the WebSphere eXtended Transaction Runtime container."
    ${CICSPATH}/bin/startCICSServices -s cold >> ${log_file} 2>&1 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
        output_message "Error occurred. Failed to start the WebSphere eXtended Transaction Runtime container."
        ACTION_FAILED="true"
    else
        output_message "WebSphere eXtended Transaction Runtime container successfully started."
    fi

 
  elif [[ "${1}" = "removeRA" ]]
  then
    output_message ""
    output_message "------------------------------------------------------------"
    output_message ""
    output_message " Application server environment:"
    output_message ""
    output_message " Profile name: " ${Profile}
    output_message " Cell name: " ${Cell}
    output_message " Node name: " ${Node}
    output_message " Server name: " ${Server}
    output_message ""
    output_message "------------------------------------------------------------"
    output_message ""
    output_message "`basename ${0}` will perform the following actions:"
    output_message ""
    output_message "1. The sample: ${CICSPATH}/samples/J2EE/SMDemo.war will be removed\nfrom the application server."
    output_message ""
    output_message "2. The sample: ${CICSPATH}/samples/J2EE/CCWSample.war will be removed\nfrom the application server."
    output_message ""
    output_message "3. The WebSphere eXtended Transaction Runtime SCA Component will be removed from\n the application server."
    output_message ""
    output_message "4. The WebSphere eXtended Transaction Runtime Resource Adapter will be removed from\n the application server."
    output_message ""
    output_message "5. The WebSphere eXtended Transaction Runtime system administration contributions\n will be removed from the application server."
    output_message ""
    output_message "------------------------------------------------------------"
    output_message "NOTE: `basename ${0}` will start the WebSphere Application Server to\n uninstall the Resource Adapter, SCA Component and Samples and then stop the server\n before uninstalling the system administration contributions."
    output_message ""
    output_message "------------------------------------------------------------"
    output_message ""
    output_message "This may take a few minutes. Please wait..."
    output_message ""
    output_message ""
    checkServerStatus


    output_message ""
    startServer 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
	exit ${RETVAL} 
    fi

    output_message ""
    output_message "Removing the sample: SMDemo."
    undeploySample "SMDemo" 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       output_message "Error occurred. Failed to remove the WebSphere eXtended Transaction Runtime supplied sample: SMDemo. " 
       ACTION_FAILED="true"
    else
       output_message "Removal of sample: SMDemo completed successfully."
    fi


    output_message ""
    output_message "Removing the sample: CCWSample."
    undeploySample "CCWSample" 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       output_message "Error occurred. Failed to remove the WebSphere eXtended Transaction Runtime supplied sample: CCWSample. " 
       ACTION_FAILED="true"
    else
       output_message "Removal of sample: CCWSample completed successfully."
    fi


    output_message ""
    output_message "Removing the WebSphere eXtended Transaction Runtime SCA Component."
    removeSCA 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       output_message "Error occurred. Failed to remove the WebSphere eXtended Transaction Runtime SCA Component. " 
       ACTION_FAILED="true"
    else
       output_message "Removal of the WebSphere eXtended Transaction Runtime SCA Component completed successfully."
    fi


    output_message ""
    output_message "Removing the WebSphere eXtended Transaction Runtime Resource Adapter."
    removeCCRA 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       output_message "Error occurred. Failed to remove the WebSphere eXtended Transaction Runtime Resource Adapter. " 
       ACTION_FAILED="true"
    else
       output_message "Removal of the WebSphere eXtended Transaction Runtime Resource Adapter completed successfully."
    fi


    output_message ""
    stopServer 

    output_message ""
    output_message "Removing WebSphere eXtended Transaction Runtime system administration contributions. "
    removeSysAdm 
    RETVAL=$?
    if (( ${RETVAL} != 0 ))
    then
       output_message  "Error occurred. Failed to remove the WebSphere eXtended Transaction Runtime system administration contributions."
       ACTION_FAILED="true"
    else
       output_message "Removal of  WebSphere eXtended Transaction Runtime system administration contributions completed successfully."
    fi
  fi

  if [[ "${ACTION_FAILED}" = "true" ]]
  then
    output_message ""
    output_message ""
    output_message "The command failed to perform the tasks."
    echo "Check the log file: ${log_file} for details."
    exit 1
  fi

