#!/bin/ksh
# NAME:	     ValidateWASEnv.fnc
# VERSION:    1.2 
#                                                         
#   (C) COPYRIGHT International Business Machines Corp.   
#   2011                                            
#   All Rights Reserved                                   
#   Licensed Materials - Property of IBM                  
#   5725-C89                                              
#                                                         
#   US Government Users Restricted Rights -               
#   Use, duplication or disclosure restricted by          
#   GSA ADP Schedule Contract with IBM Corp.              
#                                                         
#                                                                       
#            NOTICE TO USERS OF THE SOURCE CODE EXAMPLES                
#                                                                       
# INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THE SOURCE CODE  
# EXAMPLES, BOTH INDIVIDUALLY AND AS ONE OR MORE GROUPS, AS IS          
# WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,            
# INCLUDING, BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF               
# MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE     
# RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOURCE CODE EXAMPLES,   
# BOTH INDIVIDUALLY AND AS ONE OR MORE GROUPS, IS WITH YOU.  SHOULD     
# ANY PART OF THE SOURCE CODE EXAMPLES PROVE DEFECTIVE, YOU (AND NOT    
# IBM) ASSUME THE ENTIRE COST OF ALL NECESSARY SERVICING, REPAIR OR     
# CORRECTION.  THIS PROGRAM MAY BE USED, EXECUTED, COPIED, MODIFIED     
# AND DISTRIBUTED WITHOUT ROYALTY FOR THE PURPOSE OF DEVELOPING,        
# MARKETING, OR DISTRIBUTING.                                           
#                                                                       
#                                                                       
#                                                                       
#
# SYNOPSIS:
#
# ValidateEnv
#
# DESCRIPTION:
#
# ValidateWASEnv.fnc consists of following functions which are used sample programs 
#      debug_message()  - It redirect the message to the log file.
#      output_message() - It prints the message to the stdout and also redirects the message to the log file.
#      initialize() - Expects a single argument. Creates a log file with name <argument>.log in ${CICSPATH}/logs directory.
#      getWASInstall() - Sets the variable WAS_PROFILE_BIN with WXTR container used profile bin path.
#      acceptNodeName() - Sets the 'Node' variable with WXTR container used WAS node name.
#      checkServerStatus() - Checks the WAS server status. If it is stopped, it will start the server.
#      acceptServerName() - Sets the 'Server' variable with WXTR container used WAS name.
#      startServer() - starts the WAS server.
#      callWsadmin() - Expects a single argument. The argument is the name of the jython script to be passed to the wsadmin tool.
#      
PROGNAME=${0}                       # the program name this is invoked with

debug_message()
{
     echo $* >> ${log_file}
}

output_message()
{
     debug_message $*
     echo $*
}

initialize()
{
    # Initial Values

    if [[ "${CICSPATH}" = "" ]]
    then
      echo "Error occurred. The environment variable: CICSPATH is not set. A new installation of WebSphere eXtended Transaction Runtime requires you to logoff and re-login to reflect changes in the system environment."
      exit 1
    fi
    if [[ ! -d "${CICSPATH}" ]]
    then
      echo "Error occurred. Could not locate the WebSphere eXtended Transaction Runtime installation. CICSPATH is set to ${CICSPATH} and the directory is empty."
      exit 1
    fi
    export PATH=${PATH}:${CICSPATH}/bin:/usr/bin:/bin:/usr/sbin
    export LIBPATH=${LIBPATH}:${CICSPATH}/lib
    Machine=`uname -n`
    Node="${Machine}"Node01
    Cell="${Node}Cell"
    Server=server1
    #
    RETVAL=0
    log_file=${CICSPATH}/logs/${1}.log
    if [ ! -f ${CICSPATH}/logs ]
    then
      mkdir -p ${CICSPATH}/logs
      rm -f ${log_file}
      echo "The log file: ${log_file} will be created."
      echo ""
      touch ${log_file}
      RETVAL=$?
      if (( ${RETVAL} != 0 ))
      then
        echo "Could not create file: ${log_file}. Trying in /tmp."
        log_file=/tmp/${1}.log
        touch ${log_file}
        RETVAL=$?
        if (( ${RETVAL} != 0 ))
        then
          echo "Error occurred. Could not create file: ${log_file}."
          exit 1
        fi
      fi

    fi
    # Initial Values
    #trap to remove temporary files. Comment this to keep the files to debug.
    trap "rm -f /tmp/TempSampleConfig.py 2>/dev/null  " 0 1 2 3 15
}

getWASInstall()
{
   WXTRPATH=`getProperty CCW_REGION`
   if [[ "${WXTRPATH}" != "" ]]
   then
       folder_count=1
       for i in `echo ${WXTRPATH} | tr '/' ' '`
       do
         ((folder_count=${folder_count}+1))
       done
       ((folder_count=${folder_count}-7))
       WAS_PROFILE=`echo ${WXTRPATH} | cut -d'/' -f1-${folder_count}`
       export folder_count;
   else
       output_message "Error occurred. The WebSphere eXtended Transaction Runtime Service could not be located. A new installation of WebSphere eXtended Transaction Runtime requires you to execute the  configureCICSServices utility before executing `basename $0`"
       exit 1
   fi
   WAS_PROFILE_BIN="${WAS_PROFILE}/bin"

   if [ ! -f "${WAS_PROFILE_BIN}/serverStatus.sh" ]
   then
       output_message "Error occurred. The WebSphere eXtended Transaction Runtime Service could not be located. A new installation of WebSphere eXtended Transaction Runtime requires you to execute the  configureCICSServices utility before executing `basename $0`"
       exit 1
   fi

}
acceptNodeName()
{
  ((node_count=${folder_count}+5))
  input=`echo $WXTRPATH|cut -d'/' -f${node_count}`
  if [[ "${input}" != "" ]]
   then
     Node="${input}"
  fi
}
checkServerStatus()
{
      SERVER_STATUS="UNKNOWN"
      acceptServerName
      output_message "Checking for status of the server: ${Server}."
      output_message "You may be prompted for WAS administrative user name and password if required."
      output_message "You can check the file /tmp/checkserverStatus.log for the progress of the status check action."
      cat /dev/null > /tmp/checkserverStatus.log
      if [[ "${userNameSet}" = "true" ]] || [[ "${passwordSet}" = "true" ]]
      then
        ${WAS_PROFILE_BIN}/serverStatus.sh ${Server} -username ${userName} -password ${password} 2>&1 | tee -a /tmp/checkserverStatus.log ${log_file}
      else
        ${WAS_PROFILE_BIN}/serverStatus.sh ${Server}  2>&1 | tee -a /tmp/checkserverStatus.log  ${log_file}
      fi


      cat ${log_file} |grep "ADMU0522E" >/dev/null
      RETVAL=$?
      if (( ${RETVAL} == 0 ))
      then
        output_message "Error occurred. No server by name: ${Server} is found in the configuration."
        echo "Check the log file: ${log_file} for details."
        exit 1
      fi

      cat ${log_file}|grep "ADMU0508I" >/dev/null
      RETVAL=$?
      if (( ${RETVAL} == 0 ))
      then
        output_message "Server: ${Server} found and is Started."
        SERVER_STATUS="STARTED"
      fi

      cat ${log_file}|grep "ADMU0509I" >/dev/null
      RETVAL=$?
      if (( ${RETVAL} == 0 ))
      then
        output_message "Server: ${Server} found but appears to be stopped. Starting the server."
        startServer
        RETVAL=$?
        if (( ${RETVAL} != 0 ))
        then
             exit ${RETVAL}
        fi
      fi
      if [[ "${SERVER_STATUS}" = "UNKNOWN" ]]
      then
        output_message "Error occurred. The server: ${Server} could not be reached."
        echo "Check the log file: ${log_file} for details."
        exit 1
      fi
}

acceptServerName()
{
    ((server_count=${folder_count}+7))
    input=`echo $WXTRPATH|cut -d'/' -f${server_count}`
    if [[ "${input}" != "" ]]
    then
      Server="${input}"
    fi
}
startServer()
{
    output_message "Attempting to start the server ${Server}."
    if [[ "${SERVER_STATUS}" = "STARTED" ]]
    then
      output_message "Server: ${Server} is already started."
    else
      cat /dev/null > /tmp/checkserverStatus.log
      ${WAS_PROFILE_BIN}/startServer.sh ${Server} 2>&1 | tee -a /tmp/checkserverStatus.log ${log_file}
      cat ${log_file} |grep "ADMU3000I" >/dev/null
      RETVAL=$?
      if (( ${RETVAL} == 0 ))
      then
        output_message "Server: ${Server} is started."
        SERVER_STATUS="STARTED"
      else
        output_message "Server: ${Server} could not be started."
        SERVER_STATUS="STOPPED"
        return ${RETVAL}
      fi
    fi
}
callWsadmin()
{
    debug_message "$WAS_PROFILE_BIN/wsadmin.sh  will be executed with the following input:"
    cat ${1} >> ${log_file}
    debug_message ""
    echo "You may be prompted for WAS administrative user name and password if required."
    if [[ "${userNameSet}" = "true" ]] || [[ "${passwordSet}" = "true" ]]
    then
      $WAS_PROFILE_BIN/wsadmin.sh -f ${1} -lang jython -user ${userName} -password ${password} 2>&1 | tee -a  ${log_file}
      RETVAL=$?
    else
      $WAS_PROFILE_BIN/wsadmin.sh -f ${1} -lang jython  2>&1 | tee -a  ${log_file}
      RETVAL=$?
    fi
    if (( ${RETVAL} != 0 ))
    then
      debug_message "$WAS_PROFILE_BIN/wsadmin.sh failed with error code: ${RETVAL}"
      return ${RETVAL}
    else
      debug_message "$WAS_PROFILE_BIN/wsadmin.sh completed."
    fi

}

#
# Module what string
#
#@(#)concc,23:06:04,Nov 11 2011,IBM WebSphere eXtended Transaction Runtime 1.0.0.1 xs100-L111111
#
