      *****************************************************************
      * DATE: 11/02/04 
      * VERSION: 1.3 
      *                                                         
      *   (C) COPYRIGHT International Business Machines Corp.   
      *   2011                                            
      *   All Rights Reserved                                   
      *   Licensed Materials - Property of IBM                  
      *   5725-C89                                              
      *                                                         
      *   US Government Users Restricted Rights -               
      *   Use, duplication or disclosure restricted by          
      *   GSA ADP Schedule Contract with IBM Corp.              
      *                                                         
      *                                                                       
      *            NOTICE TO USERS OF THE SOURCE CODE EXAMPLES                
      *                                                                       
      * INTERNATIONAL BUSINESS MACHINES CORPORATION PROVIDES THE SOURCE CODE  
      * EXAMPLES, BOTH INDIVIDUALLY AND AS ONE OR MORE GROUPS, AS IS          
      * WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED,            
      * INCLUDING, BUT NOT LIMITED TO THE IMPLIED WARRANTIES OF               
      * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE.  THE ENTIRE     
      * RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOURCE CODE EXAMPLES,   
      * BOTH INDIVIDUALLY AND AS ONE OR MORE GROUPS, IS WITH YOU.  SHOULD     
      * ANY PART OF THE SOURCE CODE EXAMPLES PROVE DEFECTIVE, YOU (AND NOT    
      * IBM) ASSUME THE ENTIRE COST OF ALL NECESSARY SERVICING, REPAIR OR     
      * CORRECTION.  THIS PROGRAM MAY BE USED, EXECUTED, COPIED, MODIFIED     
      * AND DISTRIBUTED WITHOUT ROYALTY FOR THE PURPOSE OF DEVELOPING,        
      * MARKETING, OR DISTRIBUTING.                                           
      *                                                                       
      *                                                                       
      * Program to delete TSQ
      *****************************************************************
        IDENTIFICATION DIVISION.
        PROGRAM-ID.   TSQDELTE.

        ENVIRONMENT DIVISION.
        DATA DIVISION.

        WORKING-STORAGE SECTION.
        01  RESP                PIC S9(8)    BINARY.
        01  ABSTIME             PIC S9(15)   COMP-3.
        01  FORM-TIME           PIC X(8)     VALUE SPACES.
        01  READ-RECORD.
            05  TSQSTATUS       PIC X(1)     VALUE SPACES.
            05  TSQNAME         PIC X(8)     VALUE SPACES.
            05  MSG             PIC X(80)    VALUE SPACES.
        01  FLOG                PIC X(4)     VALUE 'CSMT'.
        01 MSG-TEXT             PIC X(25)    VALUE SPACES.
        01 RESP-SAVE            PIC 99.
        01 LEN                  PIC S9(4)    BINARY VALUE 80.
        01 NUMITEMS             PIC S9(4)    BINARY VALUE 0.

        LINKAGE SECTION.
        01 DFHCOMMAREA.
           05 CSTATUS      PIC X(1).
           05 CTSQNAME     PIC X(8).
           05 COMMMSG      PIC X(80).

        PROCEDURE DIVISION.

           EXEC CICS ASKTIME
                     ABSTIME    (ABSTIME)
           END-EXEC.

           EXEC CICS FORMATTIME
                     ABSTIME    (ABSTIME)
                     TIME       (FORM-TIME)
                     TIMESEP
           END-EXEC.

           MOVE DFHCOMMAREA TO READ-RECORD.

           EXEC CICS DELETEQ TS
                     QUEUE      (TSQNAME)
                     RESP       (RESP)
           END-EXEC.

      *-----------------------------------------------------------------
      * Validate the RESP values
      *-----------------------------------------------------------------
            EVALUATE RESP
               WHEN DFHRESP(NORMAL)
                    STRING FORM-TIME
                           '  : DELETING TSQ '
                           TSQNAME
                           ' SUCCESSFUL'
                           DELIMITED BY SIZE
                           INTO MSG
                    END-STRING
                    PERFORM SEND-MSG
                    MOVE 'S' TO TSQSTATUS
               WHEN OTHER
                    STRING FORM-TIME
                           '  : DELETING TSQ '
                           TSQNAME
                           ' FAILED'
                           DELIMITED BY SIZE
                           INTO MSG
                    END-STRING
                    PERFORM RESP-ERROR
           END-EVALUATE.


      *-----------------------------------------------------------------
      * Complete the transaction
      *-----------------------------------------------------------------
       RETURN-LABEL.

           MOVE READ-RECORD TO DFHCOMMAREA.
           EXEC CICS RETURN
           END-EXEC.

      *-----------------------------------------------------------------
      *  handle unexpected responses
      *-----------------------------------------------------------------

       RESP-ERROR.

           MOVE SPACES TO MSG.

           EVALUATE RESP
             WHEN DFHRESP(IOERR)      MOVE '- IOERR'     TO MSG-TEXT
             WHEN DFHRESP(NORMAL)     MOVE '- NORMAL'    TO MSG-TEXT
             WHEN DFHRESP(ERROR)      MOVE '- ERROR'     TO MSG-TEXT
             WHEN DFHRESP(INVREQ)     MOVE '- INVREQ'    TO MSG-TEXT
             WHEN DFHRESP(IOERR)      MOVE '- IOERR'     TO MSG-TEXT
             WHEN DFHRESP(NOSPACE)    MOVE '- NOSPACE'   TO MSG-TEXT
             WHEN DFHRESP(NOTOPEN)    MOVE '- NOTOPEN'   TO MSG-TEXT
             WHEN DFHRESP(ILLOGIC)    MOVE '- ILLOGIC'   TO MSG-TEXT
             WHEN DFHRESP(LENGERR)    MOVE '- LENGERR'   TO MSG-TEXT
             WHEN DFHRESP(QZERO)      MOVE '- QZERO'     TO MSG-TEXT
             WHEN DFHRESP(QBUSY)      MOVE '- QBUSY'     TO MSG-TEXT
             WHEN DFHRESP(ITEMERR)    MOVE '- ITEMERR'   TO MSG-TEXT
             WHEN DFHRESP(QIDERR)     MOVE '- QIDERR'    TO MSG-TEXT
             WHEN DFHRESP(ISCINVREQ)  MOVE '- ISCINVREQ' TO MSG-TEXT
             WHEN DFHRESP(NOTAUTH)    MOVE '- NOTAUTH'   TO MSG-TEXT
             WHEN DFHRESP(DISABLED)   MOVE '- DISABLED'  TO MSG-TEXT
             WHEN DFHRESP(SYSBUSY)    MOVE '- SYSBUSY'   TO MSG-TEXT
             WHEN DFHRESP(TERMERR)    MOVE '- TERMERR'   TO MSG-TEXT
             WHEN OTHER
                  MOVE RESP TO RESP-SAVE
                  STRING '- EIBRESP(' RESP-SAVE ')'
                         DELIMITED BY SIZE INTO MSG-TEXT
           END-EVALUATE.
           MOVE MSG-TEXT TO MSG.
           PERFORM SEND-MSG.

              MOVE 'F' TO TSQSTATUS.
              MOVE MSG-TEXT TO MSG.

           GO TO RETURN-LABEL.

      *-----------------------------------------------------------------
      * send messages to CSMT log
      *-----------------------------------------------------------------
       SEND-MSG.

           EXEC CICS WRITEQ TD
                        QUEUE   (FLOG)
                        FROM    (MSG)
                        LENGTH  (80)
                        RESP    (RESP)
           END-EXEC.

